#!/bin/bash

conda create -p Env$1 python=3.7 -y
source activate Env$1

pip install -r REQUIREMENTS_$1.txt
pip install -U django-cms==$1
pip install -U django==2.2.9
pip install -U djangocms_bootstrap4==1.5.0
pip install -U html5lib==1.0.1
